@@ -11,6 +11,7 @@
 
 #include <R.h>
 #include <Rinternals.h>
+#include <stdbool.h>
 
 #define SEXPPTR(x) ((SEXP *)DATAPTR(x))  // to avoid overhead of looped VECTOR_ELT
 #define SEXPPTR_RO(x) ((const SEXP *)DATAPTR_RO(x))  // to avoid overhead of looped VECTOR_ELT
@@ -42,12 +43,15 @@ SEXP setcolorder(SEXP, SEXP);
 SEXP subsetDT(SEXP, SEXP, SEXP, SEXP);
 SEXP subsetCols(SEXP, SEXP, SEXP);
 SEXP subsetVector(SEXP, SEXP, SEXP);
+void subsetVectorRaw(SEXP, SEXP, SEXP, const bool);
 SEXP Calloccol(SEXP);
+void writeValue(SEXP, SEXP, const int, const int);
+void writeNA(SEXP, const int, const int);
 
 // Native collapse functions
 void matCopyAttr(SEXP out, SEXP x, SEXP Rdrop, int ng);
 void DFcopyAttr(SEXP out, SEXP x, int ng);
-SEXP falloc(SEXP, SEXP);
+SEXP falloc(SEXP, SEXP, SEXP);
 SEXP frange(SEXP x, SEXP Rnarm);
 SEXP fdist(SEXP x, SEXP vec, SEXP Rret, SEXP Rnthreads);
 SEXP fnrowC(SEXP x);
@@ -82,12 +86,20 @@ SEXP Cissorted(SEXP x, SEXP strictly);
 SEXP groupVec(SEXP X, SEXP starts, SEXP sizes);
 SEXP groupAtVec(SEXP X, SEXP starts, SEXP naincl);
 SEXP funiqueC(SEXP x);
+SEXP fmatchC(SEXP x, SEXP table, SEXP nomatch, SEXP count, SEXP overid);
+SEXP coerce_to_equal_types(SEXP x, SEXP table);
+void count_match(SEXP res, int nt, int nmv);
 SEXP createeptr(SEXP x);
 SEXP geteptr(SEXP x);
 SEXP fcrosscolon(SEXP x, SEXP ngp, SEXP y, SEXP ckna);
 SEXP fwtabulate(SEXP x, SEXP w, SEXP ngp, SEXP ckna);
 SEXP vecgcd(SEXP x);
 SEXP all_funs(SEXP x);
+SEXP unlock_collapse_namespace(SEXP env);
+void writeValueByIndex(SEXP target, SEXP source, const int from, SEXP index);
+SEXP pivot_long(SEXP data, SEXP ind, SEXP idcol);
+SEXP pivot_wide(SEXP index, SEXP id, SEXP column, SEXP fill, SEXP Rnthreads);
+SEXP sort_merge_join(SEXP x, SEXP table, SEXP ot, SEXP count);
 // fnobs rewritten in C:
 SEXP fnobsC(SEXP x, SEXP Rng, SEXP g);
 SEXP fnobsmC(SEXP x, SEXP Rng, SEXP g, SEXP Rdrop);
